@@ -30,7 +30,7 @@ from datetime import datetime
 from pprint import pformat
 from threading import local
 from copy import deepcopy
-version = '0.6'
+version = '0.6.1'
 
 
 def itemize_length(items):
@@ -59,8 +59,6 @@ class CallBack(object):
 
 def that_with_context(setup=None, teardown=None):
     def dec(func):
-        func.__name__ = "test_%s" % func.__name__
-
         def wrap(*args, **kw):
             context = local()
 
